bl_info = {
    "name": "Shading +",
    "description": "A shading pie menu made for vehicle designers",
    "author": "1P2D <me@1p2d.com>",
    "version": (1,0,9),
    "blender": (4,2,0),
    "category": "Object",
    "location": "3D View",
    "doc_url": "https://www.1p2d.com/"
}

import bpy
from . import viewportcolors, operators, menus, ui, matcaps, preferences, icons, compositor

addon_keymaps = []


def register():

    compositor.register()

    viewportcolors.register()
    ui.register()  # Ensure ui is registered here

    # Register Preferences
    preferences.register()
    
    # Register Operators
    operators.register()

    matcaps.register()
    
    # Register Menus
    menus.register()

    icons.load_custom_icons()
    
    # Register Keymaps (if any)
    register_keymaps()


    
def register_keymaps():
    wm = bpy.context.window_manager
    kc = wm.keyconfigs.addon

    if kc:
        # Example Keymap Registration (Customize as needed)
        km = kc.keymaps.new(name='3D View', space_type='VIEW_3D')
        kmi = km.keymap_items.new('wm.call_menu_pie', 'Z', 'PRESS')
        kmi.properties.name = "PIE_MT_1P2D_shading_plus"
        addon_keymaps.append((km, kmi))


def unregister_keymaps():
    # Remove all keymaps
    for km, kmi in addon_keymaps:
        km.keymap_items.remove(kmi)
    addon_keymaps.clear()


def unregister():
    icons.unload_custom_icons()
    
    # Unregister Keymaps
    unregister_keymaps()
    
    # Unregister Menus
    menus.unregister()

    matcaps.unregister()
    
    # Unregister Operators
    operators.unregister()
    
    # Unregister Preferences
    preferences.unregister()

    viewportcolors.unregister()
    ui.unregister()  # Ensure ui is unregistered here

    compositor.unregister()

    



if __name__ == "__main__":
    register()
